==> 2.5.0.zip: cloudlog/application/language/czech/general_words_lang.php <==
<?php

defined('BASEPATH') OR exit('No direct script access allowed');

$lang['error_no_active_station_profile'] = 'Pozor: musíte nastavit aktivní umístění stanice.';

$lang['notice_turn_the_radio_on'] = 'Dnes jste neudělali žádná QSO spojení; je čas zapnout rádio!';

$lang['general_word_important'] = 'Důležité';
$lang['general_word_warning'] = 'Warning';
$lang['general_word_danger'] = 'DANGER';
$lang['general_word_maintenance'] = 'Maintenance';
$lang['general_word_info'] = 'Info';
$lang['general_word_choose_file'] = 'Vybrat soubor';
$lang['general_word_next'] = 'Next';
$lang['general_word_previous'] = 'Previous';
$lang['general_word_cancel'] = "Cancel";
$lang['general_word_ok'] = "OK";
$lang['general_word_attention'] = "Attention";
$lang['general_word_enabled'] = "Enabled";
$lang['general_word_disabled'] = "Disabled";
$lang['general_word_export'] = "Export";
$lang['general_word_import'] = "Import";

$lang['general_word_date'] = 'Datum';
$lang['general_word_time'] = 'Čas';
$lang['general_word_time_on'] = 'Time on';
$lang['general_word_time_off'] = 'Time off';
$lang['general_word_datetime'] = 'Datum/čas';
$lang['general_word_none'] = 'Žádné';
$lang['general_word_name'] = 'Jméno';
$lang['general_word_location'] = 'Místo';
$lang['general_word_comment'] = 'Komentář';
$lang['general_word_general'] = 'Obecné';
$lang['general_word_satellite'] = 'Satelit';
$lang['general_word_satellite_short'] = 'Sat';
$lang['general_word_notes'] = 'Poznámky';
$lang['general_word_country'] = 'Země';
$lang['general_word_city'] = 'Město';

$lang['general_word_total'] = 'Celkem';
$lang['general_word_year'] = 'Rok';
$lang['general_word_month'] = 'Měsíc';

$lang['general_word_colors'] = "Colors";
$lang['general_word_light'] = "Light/Laser";
$lang['general_word_worked'] = 'Spojeno';
$lang['general_word_worked_not_confirmed'] = "Worked not confirmed";
$lang['general_word_not_worked'] = "Not worked";
$lang['general_word_confirmed'] = 'Potvrzeno';
$lang['general_word_needed'] = 'Potřebuje se';

$lang['general_word_all'] = 'All';
$lang['general_word_no'] = 'Ne';
$lang['general_word_yes'] = 'Ano';
$lang['general_word_method'] = 'Metoda';

$lang['general_word_sent'] = 'Odesláno';
$lang['general_word_received'] = 'Přijato';
$lang['general_word_requested'] = 'Vyžádáno';
$lang['general_word_queued'] = 'Ve frontě';
$lang['general_word_table'] = "Table";
$lang['general_word_invalid_ignore'] = 'Neplatné (Ignorováno)';
$lang['general_word_qslcard'] = 'QSL karta';
$lang['general_word_qslcard_management'] = 'Správa QSL';
$lang['general_word_qslcards'] = 'QSL karty';
$lang['general_word_qslcard_direct'] = 'Přímá';
$lang['general_word_qslcard_bureau'] = 'Bureau';
$lang['general_word_qslcard_electronic'] = 'Elektronická';
$lang['general_word_qslcard_manager'] = 'Správce';
$lang['general_word_qslcard_via'] = 'Přes';
$lang['general_word_eqslcard'] = 'eQSL karta';
$lang['general_word_eqslcards'] = 'eQSL karty';
$lang['general_word_lotw'] = 'Logbook of the World';
$lang['general_word_lotw_short'] = 'LoTW';

$lang['general_word_details'] = 'Details';
$lang['general_word_qso_data'] = 'QSO Data';

$lang['general_edit_qso'] = 'Upravit QSO';
$lang['general_mark_qsl_rx_bureau'] = 'Označit QSL přijato (Bureau)';
$lang['general_mark_qsl_rx_direct'] = 'Označit QSL přijato (Přímá)';
$lang['general_mark_qsl_rx_electronic'] = 'Označit QSL přijato (Elektronicky)';
$lang['general_mark_qsl_tx_bureau'] = 'Označit QSL odesláno (Bureau)';
$lang['general_mark_qsl_tx_direct'] = 'Označit QSL odesláno (Přímá)';
$lang['general_mark_qsl_requested'] = 'Označit QSL kartu požadováno';
$lang['general_mark_qsl_requested_bureau'] = 'Označit QSL kartu požadováno (Bureau)';
$lang['general_mark_qsl_requested_direct'] = 'Označit QSL kartu požadováno (Přímá)';
$lang['general_mark_qsl_not_required'] = 'Označit QSL lístek není vyžadován';

$lang['general_delete_qso'] = 'Smazat QSO';
$lang['general_more_qso'] = 'More QSOs';

$lang['general_lookup_qrz'] = 'Lookup on QRZ.com';
$lang['general_lookup_hamqth'] = 'Lookup on HamQTH';

$lang['general_total_distance'] = 'Celková vzdálenost';

// PHP Upload Warning
$lang['gen_max_file_upload_size'] = 'Maximum file upload size is ';

// Cloudlog Terms
$lang['cloudlog_station_profile'] = 'Umístění stanice';

// ham radio terms
$lang['gen_hamradio_cq'] = "CQ";
$lang['gen_hamradio_qso'] = 'QSO';
$lang['gen_hamradio_station'] = 'Stanice';

$lang['gen_hamradio_call'] = 'Značka';
$lang['gen_hamradio_callsign'] = 'Značka';
$lang['gen_hamradio_de'] = 'De';
$lang['gen_hamradio_dx'] = 'Dx';
$lang['gen_hamradio_mode'] = 'Režim';
$lang['gen_hamradio_rst_sent'] = 'Odesláno';
$lang['gen_hamradio_rst_rcvd'] = 'Přijato';
$lang['gen_hamradio_band'] = 'Pásmo';
$lang['gen_hamradio_bandgroup'] = "Bandgroup";
$lang['gen_hamradio_band_rx'] = 'Pásmo (RX)';
$lang['gen_hamradio_frequency'] = 'Frekvence';
$lang['gen_hamradio_frequency_rx'] = 'Frekvence (RX)';
$lang['gen_hamradio_radio'] = 'Rádio';
$lang['gen_hamradio_rsts'] = 'RST (S)';
$lang['gen_hamradio_rstr'] = 'RST (R)';
$lang['gen_hamradio_refs'] = 'Refs';
$lang['gen_hamradio_myrefs'] = 'My Refs';
$lang['gen_hamradio_exchange_sent_short'] = 'Výměna (S)';
$lang['gen_hamradio_exchange_rcvd_short'] = 'Výměna (R)';
$lang['gen_hamradio_qsl'] = 'QSL';
$lang['gen_hamradio_qsltype'] = "QSL Type";
$lang['gen_hamradio_qslvia'] = 'QSL via';
$lang['gen_hamradio_qslmsg'] = 'QSL Msg';
$lang['gen_hamradio_locator'] = 'Lokátor';
$lang['gen_hamradio_transmit_power'] = 'Vysílací výkon (W)';
$lang['gen_hamradio_propagation_mode'] = 'Šíření signálu';

$lang['gen_hamradio_satellite_name'] = 'Název satelitu';
$lang['gen_hamradio_satellite_mode'] = 'Režim satelitu';

$lang['gen_hamradio_logbook'] = 'Logbook';

$lang['gen_hamradio_zones'] = 'Zones';
$lang['gen_hamradio_cq_zone'] = 'CQ zóna';
$lang['gen_hamradio_itu_zone'] = 'ITU Zone';
$lang['gen_hamradio_dxcc'] = 'DXCC';
$lang['gen_hamradio_deleted_dxcc'] = 'Smazané DXCC';
$lang['gen_hamradio_continent'] = 'Kontinent';
$lang['gen_hamradio_usa_state'] = 'Stát USA';
$lang['gen_hamradio_county_reference'] = 'Označení okresu USA';
$lang['gen_hamradio_iota_reference'] = 'IOTA označení';
$lang['gen_hamradio_sota_reference'] = 'SOTA označení';
$lang['gen_hamradio_wwff_reference'] = 'WWFF označení';
$lang['gen_hamradio_pota_reference'] = 'POTA označení';
$lang['gen_hamradio_dok'] = 'DOK';
$lang['gen_hamradio_state'] = 'Stát';
$lang['gen_hamradio_iota'] = 'IOTA';
$lang['gen_hamradio_sota'] = 'SOTA';
$lang['gen_hamradio_wwff'] = 'WWFF';
$lang['gen_hamradio_pota'] = 'POTA';
$lang['gen_hamradio_gridsquare'] = 'Lokátor';
$lang['gen_hamradio_get_gridsquare'] = 'Get Gridsquare';
$lang['gen_hamradio_distance'] = 'Vzdálenost';
$lang['gen_hamradio_operator'] = 'Operátor';

$lang['gen_hamradio_sig'] = 'Sig';
$lang['gen_hamradio_sig_info'] = 'Sig Info';

// Find your CQ/ITU Zone
$lang['gen_find_zone_cq_part1'] = "If you don't know your CQ Zone then ";
$lang['gen_find_zone_itu_part1'] = "If you don't know your ITU Zone then ";
$lang['gen_find_zone_part2'] = 'click here';
$lang['gen_find_zone_part3'] = ' to find it!';

// Dashboard Words
$lang['dashboard_you_have_had'] = 'Máte';
$lang['dashboard_qsos_today'] = 'QSO spojení dnes!';
$lang['dashboard_qso_breakdown'] = 'Počet QSO spojení';
$lang['dashboard_countries_breakdown'] = 'Počet zemí';
$lang['gen_to_date'] = 'To date';

$lang['gen_from_date'] = 'Od data';

$lang['gen_this_qso_was_confirmed_on'] = 'Toto QSO bylo potvrzeno';

$lang['error_no_logbook_found'] = 'Nebyly nalezeny žádné denníky. Musíte definovat denník! Udělejte to zde:';

$lang['copy_to_clipboard'] = 'Kopírovat do schránky';

$lang['africa'] = 'Afrika';
$lang['antarctica'] = 'Antarktida';
$lang['asia'] = 'Asie';
$lang['europe'] = 'Evropa';
$lang['northamerica'] = 'Severní Amerika';
$lang['oceania'] = 'Oceánie';
$lang['southamerica'] = 'Jižní Amerika';

$lang['gen_band_selection'] = 'Výběr pásma';
$lang['general_word_today'] = 'Dnes';

==> 2.6.4.zip: cloudlog/application/language/czech/general_words_lang.php <==
<?php

defined('BASEPATH') OR exit('No direct script access allowed');

$lang['error_no_active_station_profile'] = 'Pozor: musíte nastavit aktivní umístění stanice.';

$lang['notice_turn_the_radio_on'] = 'Dnes jste neudělali žádná QSO spojení; je čas zapnout rádio!';

$lang['general_word_important'] = 'Důležité';
$lang['general_word_warning'] = 'Warning';
$lang['general_word_danger'] = 'DANGER';
$lang['general_word_maintenance'] = 'Maintenance';
$lang['general_word_info'] = 'Info';
$lang['general_word_choose_file'] = 'Vybrat soubor';
$lang['general_word_next'] = 'Next';
$lang['general_word_previous'] = 'Previous';
$lang['general_word_cancel'] = "Cancel";
$lang['general_word_ok'] = "OK";
$lang['general_word_attention'] = "Attention";
$lang['general_word_enabled'] = "Enabled";
$lang['general_word_disabled'] = "Disabled";
$lang['general_word_export'] = "Export";
$lang['general_word_import'] = "Import";
$lang['general_word_count'] = "Count";
$lang['general_word_filtering_on'] = "Filtering on";
$lang['general_word_not_display'] = "Not display";
$lang['general_word_icon'] = "Icon";
$lang['general_word_never'] = "Never";

$lang['general_word_date'] = 'Datum';
$lang['general_word_startdate'] = "Start Date";
$lang['general_word_enddate'] = "End Date";
$lang['general_word_time'] = 'Čas';
$lang['general_word_time_on'] = 'Time on';
$lang['general_word_time_off'] = 'Time off';
$lang['general_word_datetime'] = 'Datum/čas';
$lang['general_word_none'] = 'Žádné';
$lang['general_word_name'] = 'Jméno';
$lang['general_word_location'] = 'Místo';
$lang['general_word_comment'] = 'Komentář';
$lang['general_word_general'] = 'Obecné';
$lang['general_word_satellite'] = 'Satelit';
$lang['general_word_satellite_short'] = 'Sat';
$lang['general_word_notes'] = 'Poznámky';
$lang['general_word_country'] = 'Země';
$lang['general_word_city'] = 'Město';

$lang['general_word_total'] = 'Celkem';
$lang['general_word_year'] = 'Rok';
$lang['general_word_month'] = 'Měsíc';
$lang['general_word_day'] = "Day";
$lang['general_word_days'] = "Days";

$lang['general_word_colors'] = "Colors";
$lang['general_word_light'] = "Light/Laser";
$lang['general_word_worked'] = 'Spojeno';
$lang['general_word_worked_not_confirmed'] = "Worked not confirmed";
$lang['general_word_not_worked'] = "Not worked";
$lang['general_word_confirmed'] = 'Potvrzeno';
$lang['general_word_confirmation'] = "Confirmation";
$lang['general_word_needed'] = 'Potřebuje se';

$lang['general_word_all'] = 'All';
$lang['general_word_no'] = 'Ne';
$lang['general_word_yes'] = 'Ano';
$lang['general_word_method'] = 'Metoda';

$lang['general_word_sent'] = 'Odesláno';
$lang['general_word_received'] = 'Přijato';
$lang['general_word_requested'] = 'Vyžádáno';
$lang['general_word_queued'] = 'Ve frontě';
$lang['general_word_table'] = "Table";
$lang['general_word_invalid_ignore'] = 'Neplatné (Ignorováno)';
$lang['general_word_qslcard'] = 'QSL karta';
$lang['general_word_qslcard_management'] = 'Správa QSL';
$lang['general_word_qslcards'] = 'QSL karty';
$lang['general_word_qslcard_direct'] = 'Přímá';
$lang['general_word_qslcard_bureau'] = 'Bureau';
$lang['general_word_qslcard_electronic'] = 'Elektronická';
$lang['general_word_qslcard_manager'] = 'Správce';
$lang['general_word_qslcard_via'] = 'Přes';
$lang['general_word_eqslcard'] = 'eQSL karta';
$lang['general_word_eqslcards'] = 'eQSL karty';
$lang['general_word_lotw'] = 'Logbook of the World';
$lang['general_word_lotw_short'] = 'LoTW';

$lang['general_word_details'] = 'Details';
$lang['general_word_qso_data'] = 'QSO Data';

$lang['general_edit_qso'] = 'Upravit QSO';
$lang['general_mark_qsl_rx_bureau'] = 'Označit QSL přijato (Bureau)';
$lang['general_mark_qsl_rx_direct'] = 'Označit QSL přijato (Přímá)';
$lang['general_mark_qsl_rx_electronic'] = 'Označit QSL přijato (Elektronicky)';
$lang['general_mark_qsl_tx_bureau'] = 'Označit QSL odesláno (Bureau)';
$lang['general_mark_qsl_tx_direct'] = 'Označit QSL odesláno (Přímá)';
$lang['general_mark_qsl_requested'] = 'Označit QSL kartu požadováno';
$lang['general_mark_qsl_requested_bureau'] = 'Označit QSL kartu požadováno (Bureau)';
$lang['general_mark_qsl_requested_direct'] = 'Označit QSL kartu požadováno (Přímá)';
$lang['general_mark_qsl_not_required'] = 'Označit QSL lístek není vyžadován';

$lang['general_delete_qso'] = 'Smazat QSO';
$lang['general_more_qso'] = 'More QSOs';

$lang['general_lookup_qrz'] = 'Lookup on QRZ.com';
$lang['general_lookup_hamqth'] = 'Lookup on HamQTH';

$lang['general_total_distance'] = 'Celková vzdálenost';

// PHP Upload Warning
$lang['gen_max_file_upload_size'] = 'Maximum file upload size is ';

// Cloudlog Terms
$lang['cloudlog_station_profile'] = 'Umístění stanice';

// ham radio terms
$lang['gen_hamradio_cq'] = "CQ";
$lang['gen_hamradio_qso'] = 'QSO';
$lang['gen_hamradio_station'] = 'Stanice';

$lang['gen_hamradio_call'] = 'Značka';
$lang['gen_hamradio_callsign'] = 'Značka';
$lang['gen_hamradio_prefix'] = "Prefix";
$lang['gen_hamradio_suffix'] = "Suffix";
$lang['gen_hamradio_de'] = 'De';
$lang['gen_hamradio_dx'] = 'Dx';
$lang['gen_hamradio_mode'] = 'Režim';
$lang['gen_hamradio_rst_sent'] = 'Odesláno';
$lang['gen_hamradio_rst_rcvd'] = 'Přijato';
$lang['gen_hamradio_band'] = 'Pásmo';
$lang['gen_hamradio_bandgroup'] = "Bandgroup";
$lang['gen_hamradio_band_rx'] = 'Pásmo (RX)';
$lang['gen_hamradio_frequency'] = 'Frekvence';
$lang['gen_hamradio_frequency_rx'] = 'Frekvence (RX)';
$lang['gen_hamradio_radio'] = 'Rádio';
$lang['gen_hamradio_rsts'] = 'RST (S)';
$lang['gen_hamradio_rstr'] = 'RST (R)';
$lang['gen_hamradio_refs'] = 'Refs';
$lang['gen_hamradio_myrefs'] = 'My Refs';
$lang['gen_hamradio_exchange_sent_short'] = 'Výměna (S)';
$lang['gen_hamradio_exchange_rcvd_short'] = 'Výměna (R)';
$lang['gen_hamradio_qsl'] = 'QSL';
$lang['gen_hamradio_qsltype'] = "QSL Type";
$lang['gen_hamradio_qslvia'] = 'QSL via';
$lang['gen_hamradio_qslmsg'] = 'QSL Msg';
$lang['gen_hamradio_locator'] = 'Lokátor';
$lang['gen_hamradio_transmit_power'] = 'Vysílací výkon (W)';
$lang['gen_hamradio_propagation_mode'] = 'Šíření signálu';

$lang['gen_hamradio_satellite_name'] = 'Název satelitu';
$lang['gen_hamradio_satellite_mode'] = 'Režim satelitu';

$lang['gen_hamradio_logbook'] = 'Logbook';
$lang['gen_hamradio_award'] = "Award";

$lang['gen_hamradio_zones'] = 'Zones';
$lang['gen_hamradio_cq_zone'] = 'CQ zóna';
$lang['gen_hamradio_itu_zone'] = 'ITU Zone';
$lang['gen_hamradio_dxcc'] = 'DXCC';
$lang['gen_hamradio_deleted_dxcc'] = 'Smazané DXCC';
$lang['gen_hamradio_continent'] = 'Kontinent';
$lang['gen_hamradio_usa_state'] = 'Stát USA';
$lang['gen_hamradio_county_reference'] = 'Označení okresu USA';
$lang['gen_hamradio_iota_reference'] = 'IOTA označení';
$lang['gen_hamradio_sota_reference'] = 'SOTA označení';
$lang['gen_hamradio_wwff_reference'] = 'WWFF označení';
$lang['gen_hamradio_pota_reference'] = 'POTA označení';
$lang['gen_hamradio_dok'] = 'DOK';
$lang['gen_hamradio_state'] = 'Stát';
$lang['gen_hamradio_iota'] = 'IOTA';
$lang['gen_hamradio_sota'] = 'SOTA';
$lang['gen_hamradio_wwff'] = 'WWFF';
$lang['gen_hamradio_pota'] = 'POTA';
$lang['gen_hamradio_gridsquare'] = 'Lokátor';
$lang['gen_hamradio_get_gridsquare'] = 'Get Gridsquare';
$lang['gen_hamradio_gridsquare_show'] = "Show Locator";
$lang['gen_hamradio_latitude'] = "Latitude";
$lang['gen_hamradio_longitude'] = "Longitude";
$lang['gen_hamradio_bearing'] = "Bearing";
$lang['gen_hamradio_distance'] = 'Vzdálenost';
$lang['gen_hamradio_operator'] = 'Operátor';

$lang['gen_hamradio_sig'] = 'Sig';
$lang['gen_hamradio_sig_info'] = 'Sig Info';

// Find your CQ/ITU Zone
$lang['gen_find_zone_cq_part1'] = "If you don't know your CQ Zone then";
$lang['gen_find_zone_itu_part1'] = "If you don't know your ITU Zone then";
$lang['gen_find_zone_part2'] = "click here";
$lang['gen_find_zone_part3'] = "to find it!";

// Dashboard Words
$lang['dashboard_you_have_had'] = 'Máte';
$lang['dashboard_qsos_today'] = 'QSO spojení dnes!';
$lang['dashboard_qso_breakdown'] = 'Počet QSO spojení';
$lang['dashboard_countries_breakdown'] = 'Počet zemí';
$lang['gen_to_date'] = 'To date';

$lang['gen_from_date'] = 'Od data';

$lang['gen_this_qso_was_confirmed_on'] = 'Toto QSO bylo potvrzeno';

$lang['error_no_logbook_found'] = 'Nebyly nalezeny žádné denníky. Musíte definovat denník! Udělejte to zde:';

$lang['copy_to_clipboard'] = 'Kopírovat do schránky';

$lang['africa'] = 'Afrika';
$lang['antarctica'] = 'Antarktida';
$lang['asia'] = 'Asie';
$lang['europe'] = 'Evropa';
$lang['northamerica'] = 'Severní Amerika';
$lang['oceania'] = 'Oceánie';
$lang['southamerica'] = 'Jižní Amerika';

$lang['gen_band_selection'] = 'Výběr pásma';
$lang['general_word_today'] = 'Dnes';

$lang['hams_at_no_activations_found'] = 'No upcoming activations found. Please check back later.';

$lang['datatables_language'] = "en-GB";
